# Analogy

Like in [FastAPI](https://fastapi.tiangolo.com/) or [AWS Lambda Powertools](https://docs.powertools.aws.dev/lambda/python/latest/core/event_handler/api_gateway/) you can define route depends on request path and HTTP verb.

With **Power-Event**, You can define routes depends on business rule upon your event.

This tutorial will show you how to use **Power-events** through examples, step by step.

All the code presented can be copied and used directly (_of course you need to have power-events installed_ :smile:)

!!! tip "If you come from FastAPI or lambda powertools, you will feel familiar with syntax and easy-to-use API."
